/*
 * This file is part of the Advance project.
 *
 * Copyright (C) 2004 Andrea Mazzoleni
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * In addition, as a special exception, Andrea Mazzoleni
 * gives permission to link the code of this program with
 * the MAME library (or with modified versions of MAME that use the
 * same license as MAME), and distribute linked combinations including
 * the two.  You must obey the GNU General Public License in all
 * respects for all of the code used other than MAME.  If you modify
 * this file, you may extend this exception to your version of the
 * file, but you are not obligated to do so.  If you do not wish to
 * do so, delete this exception statement from your version.
 */

/* the first match is used */

{ "tkmmpzdm", 22 }, /* 4.0 */
{ "3in1semi", 4 }, /* 4.0 */
{ "woodpek", 2 }, /* 4.0 */
{ "wg3dh", 21 }, /* 4.0 */
{ "welltris", 17 }, /* 4.0 */
{ "wwallyj", 13 }, /* 4.0 */
{ "goonies", 17 }, /* 4.0 */
{ "vsgradus", 17 }, /* 4.0 */
{ "viostorm", 32 }, /* 4.0 */
{ "vimana", 9 }, /* 4.0 */
{ "viewpoin", 8 }, /* 4.0 */
{ "victroad", 6 }, /* 4.0 */
{ "vendetta", 3 }, /* 4.0 */
{ "varth", 11 }, /* 4.0 */
{ "vandyke", 11 }, /* 4.0 */
{ "vsav", 22 }, /* 4.0 */
{ "vsav2", 19 }, /* 4.0 */
{ "vhunt2r1", 23 }, /* 4.0 */
{ "valkyrie", 4 }, /* 4.0 */
{ "vfive", 12 }, /* 4.0 */
{ "usclssic", 7 }, /* 4.0 */
{ "twinhawk", 6 }, /* 4.0 */
{ "tron", 3 }, /* 4.0 */
{ "triplep", 3 }, /* 4.0 */
{ "toypop", 3 }, /* 4.0 */
{ "todruaga", 3 }, /* 4.0 */
{ "turtles", 3 }, /* 4.0 */
{ "truxton", 5 }, /* 4.0 */
{ "tnexspce", 9 }, /* 4.0 */
{ "kof97", 6 }, /* 4.0 */
{ "karatour", 2 }, /* 4.0 */
{ "theend", 3 }, /* 4.0 */
{ "astyanax", 10 }, /* 4.0 */
{ "mrflea", 4 }, /* 4.0 */
{ "tetris", 6 }, /* 4.0 */
{ "term2", 9 }, /* 4.0 */
{ "tbowl", 4 }, /* 4.0 */
{ "tangtang", 4 }, /* 4.0 */
{ "cupfinal", 9 }, /* 4.0 */
{ "tokkae", 5 }, /* 4.0 */
{ "suzuk8h2", 2 }, /* 4.0 */
{ "suzuka8h", 2 }, /* 4.0 */
{ "susume", 34 }, /* 4.0 */
{ "sws", 13 }, /* 4.0 */
{ "sws97", 9 }, /* 4.0 */
{ "sws96", 3 }, /* 4.0 */
{ "sws95", 10 }, /* 4.0 */
{ "swcourt", 7 }, /* 4.0 */
{ "sstingry", 2 }, /* 4.0 */
{ "macross2", 5 }, /* 4.0 */
{ "sqix", 11 }, /* 4.0 */
{ "spang", 10 }, /* 4.0 */
{ "superpac", 6 }, /* 4.0 */
{ "suplup", 3 }, /* 4.0 */
{ "usg32", 3 }, /* 4.0 */
{ "superchs", 4 }, /* 4.0 */
{ "sbishi", 13 }, /* 4.0 */
{ "ssriders", 5 }, /* 4.0 */
{ "subroc3d", 3 }, /* 4.0 */
{ "strkfgtr", 11 }, /* 4.0 */
{ "strider2", 14 }, /* 4.0 */
{ "strider", 3 }, /* 4.0 */
{ "mp_sor2", 5 }, /* 4.0 */
{ "sfiii3", 6 }, /* 4.0 */
{ "sfiii2", 6 }, /* 4.0 */
{ "sf2ce", 14 }, /* 4.0 */
{ "sf2", 14 }, /* 4.0 */
{ "sfex2p", 16 }, /* 4.0 */
{ "sfa", 15 }, /* 4.0 */
{ "sf", 11 }, /* 4.0 */
{ "stmblade", 6 }, /* 4.0 */
{ "stonebal", 20 }, /* 4.0 */
{ "stinger", 4 }, /* 4.0 */
{ "sgunner2", 3 }, /* 4.0 */
{ "stargate", 11 }, /* 4.0 */
{ "starblad", 23 }, /* 4.0 */
{ "starswep", 7 }, /* 4.0 */
{ "starglad", 14 }, /* 4.0 */
{ "squash", 7 }, /* 4.0 */
{ "splatter", 4 }, /* 4.0 */
{ "speedspn", 2 }, /* 4.0 */
{ "spdcoin", 2 }, /* 4.0 */
{ "mp_soni2", 5 }, /* 4.0 */
{ "mp_sonic", 5 }, /* 4.0 */
{ "sonson", 13 }, /* 4.0 */
{ "skyalert", 4 }, /* 4.0 */
{ "shootbul", 3 }, /* 4.0 */
{ "mp_shnb3", 6 }, /* 4.0 */
{ "shadoww", 29 }, /* 4.0 */
{ "schmeisr", 11 }, /* 4.0 */
{ "sandor", 24 }, /* 4.0 */
{ "roughrac", 18 }, /* 4.0 */
{ "robotron", 11 }, /* 4.0 */
{ "revx", 14 }, /* 4.0 */
{ "rampart", 6 }, /* 4.0 */
{ "raiders5", 3 }, /* 4.0 */
{ "4in1boot", 9 }, /* 4.0 */
{ "tantr", 12 }, /* 4.0 */
{ "pushman", 3 }, /* 4.0 */
{ "pururun", 3 }, /* 4.0 */
{ "puchicar", 11 }, /* 4.0 */
{ "prikura", 19 }, /* 4.0 */
{ "prmrsocj", 10 }, /* 4.0 */
{ "pbillian", 14 }, /* 4.0 */
{ "plegends", 9 }, /* 4.0 */
{ "groovef", 23 }, /* 4.0 */
{ "polepos2", 6 }, /* 4.0 */
{ "polepos", 5 }, /* 4.0 */
{ "playball", 11 }, /* 4.0 */
{ "peterpak", 3 }, /* 4.0 */
{ "pblbeach", 19 }, /* 4.0 */
{ "pangpoms", 4 }, /* 4.0 */
{ "pow", 16 }, /* 4.0 */
{ "othellos", 20 }, /* 4.0 */
{ "orlegend", 4 }, /* 4.0 */
{ "olds103t", 5 }, /* 4.0 */
{ "opwolf", 3 }, /* 4.0 */
{ "othunder", 2 }, /* 4.0 */
{ "opaopan", 2 }, /* 4.0 */
{ "numanath", 7 }, /* 4.0 */
{ "nova2001", 10 }, /* 4.0 */
{ "nitrobal", 4 }, /* 4.0 */
{ "ninjakd2", 10 }, /* 4.0 */
{ "nbbatman", 15 }, /* 4.0 */
{ "nslasher", 5 }, /* 4.0 */
{ "mvp", 5 }, /* 4.0 */
{ "docastle", 2 }, /* 4.0 */
{ "mtrap", 35 }, /* 4.0 */
{ "mmaulers", 22 }, /* 4.0 */
{ "gdfs", 9 }, /* 4.0 */
{ "missile", 9 }, /* 4.0 */
{ "mpangj", 9 }, /* 4.0 */
{ "mwalk", 11 }, /* 4.0 */
{ "kamenrid", 4 }, /* 4.0 */
{ "martmast", 20 }, /* 4.0 */
{ "mtlchamp", 24 }, /* 4.0 */
{ "mgcrystl", 2 }, /* 4.0 */
{ "magicbub", 6 }, /* 4.0 */
{ "mplanets", 15 }, /* 4.0 */
{ "locomotn", 2 }, /* 4.0 */
{ "crshrace", 8 }, /* 4.0 */
{ "lastmisn", 10 }, /* 4.0 */
{ "kram", 6 }, /* 4.0 */
{ "kov2", 8 }, /* 4.0 */
{ "kov", 19 }, /* 4.0 */
{ "horekid", 3 }, /* 4.0 */
{ "jungler", 6 }, /* 4.0 */
{ "vshoot", 5 }, /* 4.0 */
{ "intcup94", 9 }, /* 4.0 */
{ "hotrod", 18 }, /* 4.0 */
{ "hook", 10 }, /* 4.0 */
{ "hexion", 7 }, /* 4.0 */
{ "hedpanic", 10 }, /* 4.0 */
{ "harddriv", 13 }, /* 4.0 */
{ "guwange", 15 }, /* 4.0 */
{ "gunnail", 3 }, /* 4.0 */
{ "gunforc2", 11 }, /* 4.0 */
{ "gunforce", 10 }, /* 4.0 */
{ "gunbird", 3 }, /* 4.0 */
{ "gunmast", 4 }, /* 4.0 */
{ "gundealr", 3 }, /* 4.0 */
{ "grudge", 11 }, /* 4.0 */
{ "groundfx", 13 }, /* 4.0 */
{ "gsword", 6 }, /* 4.0 */
{ "gtclassc", 4 }, /* 4.0 */
{ "gt3d", 2 }, /* 4.0 */
{ "gt2k", 2 }, /* 4.0 */
{ "gt99", 2 }, /* 4.0 */
{ "gt98", 2 }, /* 4.0 */
{ "gt97", 2 }, /* 4.0 */
{ "gaxeduel", 20 }, /* 4.0 */
{ "ghouls", 25 }, /* 4.0 */
{ "ghostlop", 5 }, /* 4.0 */
{ "gangwars", 5 }, /* 4.0 */
{ "galspnbl", 2 }, /* 4.0 */
{ "gground", 20 }, /* 4.0 */
{ "gaia", 8 }, /* 4.0 */
{ "fpoint", 5 }, /* 4.0 */
{ "f1gp2", 6 }, /* 4.0 */
{ "f1gp", 9 }, /* 4.0 */
{ "excelsr", 10 }, /* 4.0 */
{ "espgal", 6 }, /* 4.0 */
{ "emeralda", 10 }, /* 4.0 */
{ "ejihon", 22 }, /* 4.0 */
{ "eaglshot", 4 }, /* 4.0 */
{ "edf", 2 }, /* 4.0 */
{ "dynwar", 3 }, /* 4.0 */
{ "dragoona", 21 }, /* 4.0 */
{ "dbz2", 2 }, /* 4.0 */
{ "dbz", 20 }, /* 4.0 */
{ "dsaber", 3 }, /* 4.0 */
{ "dbreed", 10 }, /* 4.0 */
{ "dbzvrvs", 9 }, /* 4.0 */
{ "ddragon", 13 }, /* 4.0 */
{ "djboy", 5 }, /* 4.0 */
{ "dietgo", 3 }, /* 4.0 */
{ "dharma", 3 }, /* 4.0 */
{ "desertbr", 3 }, /* 4.0 */
{ "deroon", 11 }, /* 4.0 */
{ "denjinmk", 3 }, /* 4.0 */
{ "dstlk", 8 }, /* 4.0 */
{ "dangar", 2 }, /* 4.0 */
{ "danceyes", 11 }, /* 4.0 */
{ "bronx", 3 }, /* 4.0 */
{ "cuebrick", 13 }, /* 4.0 */
{ "cryptklr", 59 }, /* 4.0 */
{ "crzrally", 6 }, /* 4.0 */
{ "cottonbm", 20 }, /* 4.0 */
{ "coolmini", 4 }, /* 4.0 */
{ "cltchitr", 2 }, /* 4.0 */
{ "chplftb", 43 }, /* 4.0 */
{ "csprint", 2 }, /* 4.0 */
{ "captaven", 3 }, /* 4.0 */
{ "cbasebal", 6 }, /* 4.0 */
{ "cameltry", 13 }, /* 4.0 */
{ "calibr50", 2 }, /* 4.0 */
{ "cabal", 6 }, /* 4.0 */
{ "bnzabros", 12 }, /* 4.0 */
{ "bbmanwj", 11 }, /* 4.0 */
{ "blazer", 13 }, /* 4.0 */
{ "blaster", 15 }, /* 4.0 */
{ "biomtoy", 18 }, /* 4.0 */
{ "realbrk", 6 }, /* 4.0 */
{ "beastrzr", 12 }, /* 4.0 */
{ "btoads", 12 }, /* 4.0 */
{ "batcir", 8 }, /* 4.0 */
{ "bang", 15 }, /* 4.0 */
{ "bangball", 4 }, /* 4.0 */
{ "balcube", 13 }, /* 4.0 */
{ "backfire", 14 }, /* 4.0 */
{ "aurail", 3 }, /* 4.0 */
{ "asurabld", 3 }, /* 4.0 */
{ "assault", 4 }, /* 4.0 */
{ "arkarea", 4 }, /* 4.0 */
{ "ajax", 6 }, /* 4.0 */
{ "9ballsht", 43 }, /* 4.0 */
{ "astrass", 24 }, /* 4.0 */
{ "equites", 3 }, /* 4.0 */
{ "glfgreat", 4 }, /* 4.0 */
{ "hvoltage", 4 }, /* 4.0 */
{ "splndrbt", 4 }, /* 4.0 */
{ "killbldt", 20 }, /* 4.0 */
{ "lordgun", 10 }, /* 4.0 */
{ "roadriot", 10 }, /* 4.0 */
{ "winspike", 13 }, /* 4.0 */
{ "cbombers", 13 }, /* 4.0 */
{ "hsf2", 15 }, /* 4.0 */
{ "leds2011", 9 }, /* 4.0 */
{ "mirax", 18 }, /* 4.0 */
{ "cosmogng", 4 }, /* 3.11 */
{ "batsugun", 11 }, /* 3.11 */
{ "fghtatck", 9 }, /* 3.11 */
{ "hyprduel", 13 }, /* 3.11 */
{ "metalb", 7 }, /* 3.11 */
{ "bjtwin", 2 }, /* 3.11 */
{ "hyperath", 25 }, /* 3.11 */
{ "mace", 16 }, /* 3.11 */
{ "nagano98", 22 }, /* 3.11 */
{ "weddingr", 20 }, /* 3.11 */
{ "djboy", 5 }, /* 3.11 */
{ "dcclubfd", 14 }, /* 3.11 */
{ "headonch", 12 }, /* 3.11 */
{ "mosaicf2", 20 }, /* 3.11 */
{ "blitz99", 17 }, /* 3.11 */
{ "offroadc", 20 }, /* 3.11 */
{ "sss", 17 }, /* 3.11 */
{ "teetert", 11 }, /* 3.11 */
{ "tkdensho", 9 }, /* 3.11 */
{ "firebarr", 13 }, /* 3.11 */
{ "gprider1", 6 }, /* 3.11 */
{ "zombraid", 5 }, /* 3.11 */
{ "machbrkr", 3 }, /* 3.11 */
{ "bkraidu", 22 }, /* 3.11 */
{ "puyosun", 21 }, /* 3.11 */
{ "maruchan", 21 }, /* 3.11 */
{ "gametngk", 4 }, /* 3.11 */
{ "47pie2", 6 }, /* 3.11 */
{ "kirarast", 6 }, /* 3.11 */
{ "cotton2", 20 }, /* 3.11 */
{ "p47aces", 5 }, /* 3.11 */
{ "progear", 23 }, /* 3.11 */
{ "gratia", 5 }, /* 3.11 */
{ "nebulray", 3 }, /* 3.11 */
{ "twineag2", 14 }, /* 3.11 */
{ "pzloop2j", 13 }, /* 3.11 */
{ "grdforce", 19 }, /* 3.11 */
{ "batrid", 20 }, /* 3.11 */
{ "stmblade", 6 }, /* 3.11 */
{ "skullfng", 12 }, /* 3.11 */
{ "gekirido", 12 }, /* 3.11 */
{ "tcobra2", 8 }, /* 3.11 */
{ "boogwing", 7 }, /* 3.11 */
{ "brvblade", 10 }, /* 3.11 */
{ "bgaregga", 73 }, /* 3.11 */
{ "shienryu", 19 }, /* 3.11 */
{ "gseeker", 8 }, /* 3.11 */
{ "mcatadv", 2 }, /* 3.11 */
{ "1945kiii", 8 }, /* 3.11 */
{ "kbash", 17 }, /* 3.11 */
{ "bosco", 17 }, /* 3.11 */
{ "mp_gaxe2", 7 }, /* 3.11 */
{ "bonkadv", 16 }, /* 3.11 */
{ "utoukond", 15 }, /* 3.11 */
{ "acrobatm", 15 }, /* 3.11 */
{ "g13knd", 35 }, /* 3.11 */
{ "uccops", 14 }, /* 3.6 */
{ "samsho5", 4 }, /* 3.1 */
{ "mslug5", 4 }, /* 3.1 */
{ "vasara", 8 }, /* 3.1 */
{ "viostorm", 47 }, /* 3.1 */
{ "ket", 5 }, /* 3.0 */
{ "jojoba", 7 }, /* 3.0 */
{ "sfiii", 6 }, /* 3.0 */
{ "warzard", 9 }, /* 3.0 */
{ "ddp3", 6 }, /* 3.0 */
{ "dogyuun", 13 }, /* 3.0 */
{ "espgal", 6 }, /* 3.0 */
{ "kf2k3pcb", 5 }, /* 3.0 */
{ "svcpcb", 5 }, /* 3.0 */
{ "kof2003", 5 }, /* 3.0 */
{ "samsh5sp", 5 }, /* 3.0 */
{ "ms5pcb", 5 }, /* 3.0 */
{ "samsho5", 4 }, /* 3.0 */
{ "mslug5", 4 }, /* 3.0 */
{ "vasara2", 6 }, /* 3.0 */
{ "1941", 15 }, /* 0.87 */
{ "88games", 4 }, /* 0.87 */
{ "airduel", 2 }, /* 0.87 */
{ "apb", 9 }, /* 0.87 */
{ "aquarush", 10 }, /* 0.87 */
{ "arkanoid", 9 }, /* 0.87 */
{ "asterix", 13 }, /* 0.87 */
{ "avengers", 10 }, /* 0.87 */
{ "avsp", 14 }, /* 0.87 */
{ "battleg", 44 }, /* 0.87 */
{ "bbusters", 3 }, /* 0.87 */
{ "bchopper", 2 }, /* 0.87 */
{ "beastrzr", 8 }, /* 0.87 */
{ "biofreak", 14 }, /* 0.87 */
{ "blandia", 7 }, /* 0.87 */
{ "bldyror2", 8 }, /* 0.87 */
{ "bm1stmix", 144 }, /* 0.87 */
{ "bm2ndmix", 144 }, /* 0.87 */
{ "bm4thmix", 149 }, /* 0.87 */
{ "bm5thmix", 150 }, /* 0.87 */
{ "bm6thmix", 148 }, /* 0.87 */
{ "bmcompmx", 144 }, /* 0.87 */
{ "bmcorerm", 148 }, /* 0.87 */
{ "bmdct", 150 }, /* 0.87 */
{ "bounty", 6 }, /* 0.87 */
{ "brvblade", 3 }, /* 0.87 */
{ "carjmbre", 29 }, /* 0.87 */
{ "carnevil", 20 }, /* 0.87 */
{ "cbaj", 3 }, /* 0.87 */
{ "cclimbr2", 8 }, /* 0.87 */
{ "colmns97", 20 }, /* 0.87 */
{ "cybattlr", 5 }, /* 0.87 */
{ "daimakai", 6 }, /* 0.87 */
{ "daioh", 5 }, /* 0.87 */
{ "danchih", 20 }, /* 0.87 */
{ "dbz2", 2 }, /* 0.87 */
{ "ddragon", 12 }, /* 0.87 */
{ "dimahoo", 12 }, /* 0.87 */
{ "dinorex", 7 }, /* 0.87 */
{ "dkgenm72", 2 }, /* 0.87 */
{ "dkgensan", 12 }, /* 0.87 */
{ "doapp", 2 }, /* 0.87 */
{ "downtown", 5 }, /* 0.87 */
{ "dragnblz", 12 }, /* 0.87 */
{ "dsaber", 3 }, /* 0.87 */
{ "dstlk", 7 }, /* 0.87 */
{ "ehrgeiz", 7 }, /* 0.87 */
{ "eightfrc", 3 }, /* 0.87 */
{ "elandore", 18 }, /* 0.87 */
{ "enforce", 8 }, /* 0.87 */
{ "eprom", 15 }, /* 0.87 */
{ "esprade", 9 }, /* 0.87 */
{ "extdwnhl", 13 }, /* 0.87 */
{ "fgtlayer", 8 }, /* 0.87 */
{ "fourtrax", 8 }, /* 0.87 */
{ "gaunt2", 5 }, /* 0.87 */
{ "gdarius", 17 }, /* 0.87 */
{ "geostorm", 10 }, /* 0.87 */
{ "ghostlop", 13 }, /* 0.87 */
{ "ghouls", 25 }, /* 0.87 */
{ "ghoulsu", 3 }, /* 0.87 */
{ "gigawing", 14 }, /* 0.87 */
{ "gmahou", 12 }, /* 0.87 */
{ "gnbarich", 12 }, /* 0.87 */
{ "gokuparo", 11 }, /* 0.87 */
{ "gollygho", 5 }, /* 0.87 */
{ "gradius", 24 }, /* 0.87 */
{ "groovef", 20 }, /* 0.87 */
{ "gunforc2", 9 }, /* 0.87 */
{ "gunforce", 9 }, /* 0.87 */
{ "gunforcj", 13 }, /* 0.87 */
{ "guwange", 14 }, /* 0.87 */
{ "gwarrior", 23 }, /* 0.87 */
{ "hanagumi", 22 }, /* 0.87 */
{ "hcastle", 3 }, /* 0.87 */
{ "hharry", 9 }, /* 0.87 */
{ "hmcompm2", 150 }, /* 0.87 */
{ "hvnsgate", 7 }, /* 0.87 */
{ "hyprdriv", 12 }, /* 0.87 */
{ "irrmaze", 13 }, /* 0.87 */
{ "jack", 2 }, /* 0.87 */
{ "jdreddp", 2 }, /* 0.87 */
{ "jyuo8571", 10 }, /* 0.87 */
{ "kaiserkn", 10 }, /* 0.87 */
{ "karnovr", 14 }, /* 0.87 */
{ "kinst", 2 }, /* 0.87 */
{ "kinst2", 2 }, /* 0.87 */
{ "kof2000", 6 }, /* 0.87 */
{ "kof97", 14 }, /* 0.87 */
{ "kof99", 4 }, /* 0.87 */
{ "kotm", 13 }, /* 0.87 */
{ "loderndf", 20 }, /* 0.87 */
{ "luckywld", 2 }, /* 0.87 */
{ "macross2", 5 }, /* 0.87 */
{ "madshark", 5 }, /* 0.87 */
{ "magix", 2 }, /* 0.87 */
{ "mausuke", 20 }, /* 0.87 */
{ "maxrpm", 2 }, /* 0.87 */
{ "mgcldtex", 20 }, /* 0.87 */
{ "mk", 2 }, /* 0.87 */
{ "mk2", 2 }, /* 0.87 */
{ "mk3", 11 }, /* 0.87 */
{ "mrdrillr", 9 }, /* 0.87 */
{ "mystwarr", 13 }, /* 0.87 */
{ "naname", 11 }, /* 0.87 */
{ "narc", 16 }, /* 0.87 */
{ "ncv1", 6 }, /* 0.87 */
{ "nemesis", 11 }, /* 0.87 */
{ "neocup98", 7 }, /* 0.87 */
{ "ninjaw", 9 }, /* 0.87 */
{ "nwarr", 18 }, /* 0.87 */
{ "offroadc", 15 }, /* 0.87 */
{ "opwolf3", 9 }, /* 0.87 */
{ "outzone", 11 }, /* 0.87 */
{ "overdriv", 8 }, /* 0.87 */
{ "pacnpal", 13 }, /* 0.87 */
{ "pang", 5 }, /* 0.87 */
{ "pang3", 7 }, /* 0.87 */
{ "panicbom", 13 }, /* 0.87 */
{ "pbball96", 25 }, /* 0.87 */
{ "pc_cvnia", 3 }, /* 0.87 */
{ "pc_gntlt", 4 }, /* 0.87 */
{ "pc_miket", 4 }, /* 0.87 */
{ "plsmaswd", 7 }, /* 0.87 */
{ "potopoto", 13 }, /* 0.87 */
{ "powerdrv", 3 }, /* 0.87 */
{ "prehisle", 3 }, /* 0.87 */
{ "psyforce", 21 }, /* 0.87 */
{ "punisher", 8 }, /* 0.87 */
{ "puyopuy2", 7 }, /* 0.87 */
{ "puyopuyo", 10 }, /* 0.87 */
{ "puzzli", 7 }, /* 0.87 */
{ "qdrmfgp2", 40 }, /* 0.87 */
{ "racedriv", 9 }, /* 0.87 */
{ "radikalb", 11 }, /* 0.87 */
{ "radm", 2 }, /* 0.87 */
{ "rallybik", 9 }, /* 0.87 */
{ "raystorm", 16 }, /* 0.87 */
{ "recalh", 17 }, /* 0.87 */
{ "revx", 10 }, /* 0.87 */
{ "ridgeraj", 11 }, /* 0.87 */
{ "rmpgwt", 6 }, /* 0.87 */
{ "roadblst", 5 }, /* 0.87 */
{ "roadf", 7 }, /* 0.87 */
{ "rockclim", 4 }, /* 0.87 */
{ "rpatrolb", 3 }, /* 0.87 */
{ "rthun2", 3 }, /* 0.87 */
{ "rthunder", 2 }, /* 0.87 */
{ "rtype", 15 }, /* 0.87 */
{ "rtype2", 12 }, /* 0.87 */
{ "rtypeleo", 7 }, /* 0.87 */
{ "rvschool", 11 }, /* 0.87 */
{ "samsho", 14 }, /* 0.87 */
{ "samsho2", 13 }, /* 0.87 */
{ "samsho3", 12 }, /* 0.87 */
{ "samsho4", 12 }, /* 0.87 */
{ "sengoku3", 5 }, /* 0.87 */
{ "sf1", 10 }, /* 0.87 */
{ "sf2", 13 }, /* 0.87 */
{ "sf2ce", 13 }, /* 0.87 */
{ "sfa", 15 }, /* 0.87 */
{ "sfa2", 25 }, /* 0.87 */
{ "sfa3", 14 }, /* 0.87 */
{ "sfex", 7 }, /* 0.87 */
{ "sfex2", 8 }, /* 0.87 */
{ "sfex2p", 8 }, /* 0.87 */
{ "sfexp", 6 }, /* 0.87 */
{ "sgunner", 3 }, /* 0.87 */
{ "shangha2", 4 }, /* 0.87 */
{ "shangha3", 14 }, /* 0.87 */
{ "shanghai", 5 }, /* 0.87 */
{ "shangkid", 9 }, /* 0.87 */
{ "shanhigw", 23 }, /* 0.87 */
{ "shngmtkb", 4 }, /* 0.87 */
{ "shocktro", 12 }, /* 0.87 */
{ "simpbowl", 35 }, /* 0.87 */
{ "sncwgltd", 4 }, /* 0.87 */
{ "starblad", 33 }, /* 0.87 */
{ "starglad", 7 }, /* 0.87 */
{ "stdragon", 11 }, /* 0.87 */
{ "stocker", 11 }, /* 0.87 */
{ "strider", 2 }, /* 0.87 */
{ "strider2", 8 }, /* 0.87 */
{ "striderj", 2 }, /* 0.87 */
{ "surfplnt", 8 }, /* 0.87 */
{ "susume", 26 }, /* 0.87 */
{ "sws99", 9 }, /* 0.87 */
{ "tceptor", 3 }, /* 0.87 */
{ "techromn", 4 }, /* 0.87 */
{ "tekken3", 15 }, /* 0.87 */
{ "term2", 8 }, /* 0.87 */
{ "tetrisp", 10 }, /* 0.87 */
{ "tgmj", 13 }, /* 0.87 */
{ "timekill", 4 }, /* 0.87 */
{ "tmnt", 9 }, /* 0.87 */
{ "tondemo", 2 }, /* 0.87 */
{ "ts2", 12 }, /* 0.87 */
{ "undrfire", 8 }, /* 0.87 */
{ "uopoko", 10 }, /* 0.87 */
{ "vampj", 8 }, /* 0.87 */
{ "vhunt2r1", 26 }, /* 0.87 */
{ "viewpoin", 12 }, /* 0.87 */
{ "vigilant", 4 }, /* 0.87 */
{ "vr", 4 }, /* 0.87 */
{ "vsav", 25 }, /* 0.87 */
{ "vsav2", 25 }, /* 0.87 */
{ "winterht", 20 }, /* 0.87 */
{ "xevious", 12 }, /* 0.87 */
{ "zedblade", 14 }, /* 0.87 */
{ "zunkyou", 12 }, /* 0.87 */
{ "zupapa", 8 }, /* 0.87 */
{ "1941", 15 }, /* 0.81 */
{ "1944", 13 }, /* 0.81 */
{ "19xx", 8 }, /* 0.81 */
{ "3wonders", 11 }, /* 0.81 */
{ "88games", 5 }, /* 0.81 */
{ "aerofgt", 4 }, /* 0.81 */
{ "agallet", 18 }, /* 0.81 */
{ "airbustr", 11 }, /* 0.81 */
{ "aliens", 7 }, /* 0.81 */
{ "amidar", 4 }, /* 0.81 */
{ "anteater", 3 }, /* 0.81 */
{ "aquajack", 2 }, /* 0.81 */
{ "arabfgt", 12 }, /* 0.81 */
{ "arabianm", 3 }, /* 0.81 */
{ "arbalest", 4 }, /* 0.81 */
{ "area51", 10 }, /* 0.81 */
{ "arkanoid", 8 }, /* 0.81 */
{ "arkarea", 3 }, /* 0.81 */
{ "arkretrn", 11 }, /* 0.81 */
{ "arlingtn", 5 }, /* 0.81 */
{ "armedf", 6 }, /* 0.81 */
{ "armwarr1", 6 }, /* 0.81 */
{ "ashura", 4 }, /* 0.81 */
{ "asterix", 9 }, /* 0.81 */
{ "asuka", 10 }, /* 0.81 */
{ "athena", 5 }, /* 0.81 */
{ "avengers", 10 }, /* 0.81 */
{ "avsp", 14 }, /* 0.81 */
{ "balcube", 13 }, /* 0.81 */
{ "bankp", 3 }, /* 0.81 */
{ "baraduke", 3 }, /* 0.81 */
{ "batcir", 8 }, /* 0.81 */
{ "batrider", 21 }, /* 0.81 */
{ "battlane", 6 }, /* 0.81 */
{ "battleg", 45 }, /* 0.81 */
{ "battlnts", 3 }, /* 0.81 */
{ "bbakraid", 22 }, /* 0.81 */
{ "bbmanw", 8 }, /* 0.81 */
{ "beezer", 29 }, /* 0.81 */
{ "bigrun", 2 }, /* 0.81 */
{ "biomtoy", 18 }, /* 0.81 */
{ "bionicc", 3 }, /* 0.81 */
{ "blasted", 5 }, /* 0.81 */
{ "blastoff", 7 }, /* 0.81 */
{ "blazeon", 6 }, /* 0.81 */
{ "blckgalb", 4 }, /* 0.81 */
{ "blktiger", 3 }, /* 0.81 */
{ "blmbycar", 12 }, /* 0.81 */
{ "block", 13 }, /* 0.81 */
{ "blocken", 15 }, /* 0.81 */
{ "blockhl", 5 }, /* 0.81 */
{ "bloodstm", 6 }, /* 0.81 */
{ "blswhstl", 7 }, /* 0.81 */
{ "blzntrnd", 19 }, /* 0.81 */
{ "bmaster", 10 }, /* 0.81 */
{ "bombjack", 21 }, /* 0.81 */
{ "bonzeadv", 3 }, /* 0.81 */
{ "bottom9", 11 }, /* 0.81 */
{ "bouldash", 4 }, /* 0.81 */
{ "bowlrama", 20 }, /* 0.81 */
{ "boxyboy", 3 }, /* 0.81 */
{ "brival", 12 }, /* 0.81 */
{ "bshark", 10 }, /* 0.81 */
{ "bssoccer", 8 }, /* 0.81 */
{ "btlkroad", 3 }, /* 0.81 */
{ "bubblem", 5 }, /* 0.81 */
{ "bubbles", 11 }, /* 0.81 */
{ "bublbob2", 5 }, /* 0.81 */
{ "bucky", 8 }, /* 0.81 */
{ "burglarx", 6 }, /* 0.81 */
{ "burnforc", 15 }, /* 0.81 */
{ "butasan", 19 }, /* 0.81 */
{ "cabal", 10 }, /* 0.81 */
{ "cachat", 8 }, /* 0.81 */
{ "cadash", 3 }, /* 0.81 */
{ "cairblad", 4 }, /* 0.81 */
{ "cameltry", 12 }, /* 0.81 */
{ "capbowl", 6 }, /* 0.81 */
{ "captcomm", 12 }, /* 0.81 */
{ "cawing", 15 }, /* 0.81 */
{ "cbasebal", 6 }, /* 0.81 */
{ "ccastles", 7 }, /* 0.81 */
{ "cclimbr2", 6 }, /* 0.81 */
{ "champwr", 7 }, /* 0.81 */
{ "chasehq", 6 }, /* 0.81 */
{ "cheesech", 5 }, /* 0.81 */
{ "cheyenne", 28 }, /* 0.81 */
{ "chiller", 30 }, /* 0.81 */
{ "circusc", 5 }, /* 0.81 */
{ "cischeat", 3 }, /* 0.81 */
{ "citybomb", 10 }, /* 0.81 */
{ "citycon", 5 }, /* 0.81 */
{ "claypign", 23 }, /* 0.81 */
{ "cleopatr", 10 }, /* 0.81 */
{ "columns2", 4 }, /* 0.81 */
{ "combasc", 5 }, /* 0.81 */
{ "combat", 29 }, /* 0.81 */
{ "commando", 12 }, /* 0.81 */
{ "contra", 14 }, /* 0.81 */
{ "contra", 15 }, /* 0.81 */
{ "cosmccop", 5 }, /* 0.81 */
{ "cracksht", 25 }, /* 0.81 */
{ "crimfght", 5 }, /* 0.81 */
{ "crush", 7 }, /* 0.81 */
{ "cshift", 12 }, /* 0.81 */
{ "ctribe", 6 }, /* 0.81 */
{ "cubybop", 6 }, /* 0.81 */
{ "cuebrick", 13 }, /* 0.81 */
{ "cybattlr", 4 }, /* 0.81 */
{ "cybots", 17 }, /* 0.81 */
{ "cyvern", 10 }, /* 0.81 */
{ "dadandrn", 57 }, /* 0.81 */
{ "daioh", 4 }, /* 0.81 */
{ "dangseed", 16 }, /* 0.81 */
{ "daraku", 14 }, /* 0.81 */
{ "darius", 5 }, /* 0.81 */
{ "darius2", 11 }, /* 0.81 */
{ "dariusg", 9 }, /* 0.81 */
{ "dblaxle", 6 }, /* 0.81 */
{ "dbz2", 3 }, /* 0.81 */
{ "dcon", 6 }, /* 0.81 */
{ "ddenlovr", 9 }, /* 0.81 */
{ "ddonpach", 34 }, /* 0.81 */
{ "ddragon", 13 }, /* 0.81 */
{ "ddribble", 9 }, /* 0.81 */
{ "ddsom", 7 }, /* 0.81 */
{ "ddtod", 17 }, /* 0.81 */
{ "deadconx", 3 }, /* 0.81 */
{ "defender", 13 }, /* 0.81 */
{ "demoderb", 2 }, /* 0.81 */
{ "demonwld", 4 }, /* 0.81 */
{ "devilw", 17 }, /* 0.81 */
{ "devstors", 4 }, /* 0.81 */
{ "dfeveron", 20 }, /* 0.81 */
{ "diamond", 7 }, /* 0.81 */
{ "digdug", 12 }, /* 0.81 */
{ "digdug2", 6 }, /* 0.81 */
{ "dimahoo", 12 }, /* 0.81 */
{ "dino", 6 }, /* 0.81 */
{ "dinorex", 6 }, /* 0.81 */
{ "dirtfoxj", 16 }, /* 0.81 */
{ "dleague", 7 }, /* 0.81 */
{ "docastle", 1 }, /* 0.81 */
{ "dogfight", 3 }, /* 0.81 */
{ "domino", 8 }, /* 0.81 */
{ "dondokod", 5 }, /* 0.81 */
{ "donpachi", 16 }, /* 0.81 */
{ "dotron", 3 }, /* 0.81 */
{ "downtown", 6 }, /* 0.81 */
{ "dragngun", 4 }, /* 0.81 */
{ "drgnmst", 5 }, /* 0.81 */
{ "drifto94", 13 }, /* 0.81 */
{ "driftout", 10 }, /* 0.81 */
{ "dsaber", 4 }, /* 0.81 */
{ "dsoccr94", 11 }, /* 0.81 */
{ "dspirit", 3 }, /* 0.81 */
{ "dstlk", 9 }, /* 0.81 */
{ "dungeonm", 7 }, /* 0.81 */
{ "dw", 4 }, /* 0.81 */
{ "dyger", 8 }, /* 0.81 */
{ "dynablst", 7 }, /* 0.81 */
{ "earthjkr", 9 }, /* 0.81 */
{ "ecofghtr", 13 }, /* 0.81 */
{ "eightfrc", 3 }, /* 0.81 */
{ "elvactr", 9 }, /* 0.81 */
{ "eprom", 11 }, /* 0.81 */
{ "esckids", 3 }, /* 0.81 */
{ "esprade", 9 }, /* 0.81 */
{ "exctsccr", 3 }, /* 0.81 */
{ "extdwnhl", 14 }, /* 0.81 */
{ "exterm", 3 }, /* 0.81 */
{ "extrmatn", 2 }, /* 0.81 */
{ "exzisus", 7 }, /* 0.81 */
{ "f1gp", 9 }, /* 0.81 */
{ "f1gp2", 6 }, /* 0.81 */
{ "f1gpstar", 3 }, /* 0.81 */
{ "faceoff", 11 }, /* 0.81 */
{ "fastlane", 9 }, /* 0.81 */
{ "ffight", 13 }, /* 0.81 */
{ "fhawk", 2 }, /* 0.81 */
{ "finalb", 6 }, /* 0.81 */
{ "finehour", 11 }, /* 0.81 */
{ "fitegolf", 5 }, /* 0.81 */
{ "flstory", 5 }, /* 0.81 */
{ "fncywld", 7 }, /* 0.81 */
{ "footchmp", 5 }, /* 0.81 */
{ "forgottn", 11 }, /* 0.81 */
{ "friskyt", 10 }, /* 0.81 */
{ "frogger", 2 }, /* 0.81 */
{ "fround", 7 }, /* 0.81 */
{ "fshark", 11 }, /* 0.81 */
{ "fstarfrc", 11 }, /* 0.81 */
{ "ftsoccer", 4 }, /* 0.81 */
{ "ga2", 7 }, /* 0.81 */
{ "gaia", 7 }, /* 0.81 */
{ "galaga", 14 }, /* 0.81 */
{ "galaga88", 3 }, /* 0.81 */
{ "galaxian", 4 }, /* 0.81 */
{ "galmedes", 7 }, /* 0.81 */
{ "galpani4", 10 }, /* 0.81 */
{ "galpanic", 2 }, /* 0.81 */
{ "galpanis", 11 }, /* 0.81 */
{ "galpans2", 5 }, /* 0.81 */
{ "gaplus", 8 }, /* 0.81 */
{ "gberet", 7 }, /* 0.81 */
{ "gbusters", 7 }, /* 0.81 */
{ "gcpinbal", 4 }, /* 0.81 */
{ "gekirido", 12 }, /* 0.81 */
{ "gemini", 12 }, /* 0.81 */
{ "gghost", 12 }, /* 0.81 */
{ "ghouls", 25 }, /* 0.81 */
{ "gigawing", 14 }, /* 0.81 */
{ "gijoe", 7 }, /* 0.81 */
{ "gimeabrk", 13 }, /* 0.81 */
{ "ginkun", 15 }, /* 0.81 */
{ "gng", 8 }, /* 0.81 */
{ "gogomile", 2 }, /* 0.81 */
{ "gokuparo", 12 }, /* 0.81 */
{ "goldnaxe", 6 }, /* 0.81 */
{ "gollygho", 6 }, /* 0.81 */
{ "gradius3", 15 }, /* 0.81 */
{ "grdians", 10 }, /* 0.81 */
{ "gridiron", 5 }, /* 0.81 */
{ "growl", 7 }, /* 0.81 */
{ "gseeker", 8 }, /* 0.81 */
{ "gstriker", 22 }, /* 0.81 */
{ "gtg", 6 }, /* 0.81 */
{ "gtg2", 7 }, /* 0.81 */
{ "gtmr", 4 }, /* 0.81 */
{ "gtmr2", 4 }, /* 0.81 */
{ "gulfwar2", 10 }, /* 0.81 */
{ "gunbird", 3 }, /* 0.81 */
{ "gunbird2", 11 }, /* 0.81 */
{ "gunbustr", 7 }, /* 0.81 */
{ "gundhara", 2 }, /* 0.81 */
{ "gunforc2", 11 }, /* 0.81 */
{ "gunforce", 11 }, /* 0.81 */
{ "gunfront", 5 }, /* 0.81 */
{ "gunlock", 8 }, /* 0.81 */
{ "gunsmoke", 4 }, /* 0.81 */
{ "guwange", 15 }, /* 0.81 */
{ "gwar", 5 }, /* 0.81 */
{ "gwarrior", 23 }, /* 0.81 */
{ "gyruss", 3 }, /* 0.81 */
{ "hanagumi", 20 }, /* 0.81 */
{ "hardhead", 8 }, /* 0.81 */
{ "hardyard", 4 }, /* 0.81 */
{ "hasamu", 5 }, /* 0.81 */
{ "hatris", 11 }, /* 0.81 */
{ "hattrick", 11 }, /* 0.81 */
{ "hbarrel", 6 }, /* 0.81 */
{ "heberpop", 26 }, /* 0.81 */
{ "hellfire", 4 }, /* 0.81 */
{ "hharry", 9 }, /* 0.81 */
{ "higemaru", 3 }, /* 0.81 */
{ "hiimpact", 2 }, /* 0.81 */
{ "hitice", 6 }, /* 0.81 */
{ "hitnmiss", 26 }, /* 0.81 */
{ "hopprobo", 2 }, /* 0.81 */
{ "hotchase", 17 }, /* 0.81 */
{ "hvymetal", 46 }, /* 0.81 */
{ "hydra", 2 }, /* 0.81 */
{ "hyperspt", 2 }, /* 0.81 */
{ "hyprdelj", 13 }, /* 0.81 */
{ "ikari", 6 }, /* 0.81 */
{ "ikari3", 13 }, /* 0.81 */
{ "imgfight", 5 }, /* 0.81 */
{ "inferno", 14 }, /* 0.81 */
{ "inthunt", 10 }, /* 0.81 */
{ "intrepid", 6 }, /* 0.81 */
{ "ironhors", 4 }, /* 0.81 */
{ "jackal", 6 }, /* 0.81 */
{ "jailbrek", 2 }, /* 0.81 */
{ "jitsupro", 5 }, /* 0.81 */
{ "jjsquawk", 3 }, /* 0.81 */
{ "journey", 4 }, /* 0.81 */
{ "joust", 11 }, /* 0.81 */
{ "joust2", 14 }, /* 0.81 */
{ "jrpacman", 5 }, /* 0.81 */
{ "jumpbug", 2 }, /* 0.81 */
{ "jumpshot", 4 }, /* 0.81 */
{ "kaiserkn", 7 }, /* 0.81 */
{ "karianx", 8 }, /* 0.81 */
{ "karnov", 5 }, /* 0.81 */
{ "kengo", 9 }, /* 0.81 */
{ "kick", 8 }, /* 0.81 */
{ "kicker", 14 }, /* 0.81 */
{ "kicknrun", 1 }, /* 0.81 */
{ "kikcubic", 7 }, /* 0.81 */
{ "kingofb", 13 }, /* 0.81 */
{ "kittenk", 9 }, /* 0.81 */
{ "klax", 5 }, /* 0.81 */
{ "knights", 13 }, /* 0.81 */
{ "kod", 9 }, /* 0.81 */
{ "konamigt", 8 }, /* 0.81 */
{ "koshien", 10 }, /* 0.81 */
{ "kroozr", 4 }, /* 0.81 */
{ "krzybowl", 3 }, /* 0.81 */
{ "ktiger2", 9 }, /* 0.81 */
{ "kyukaidk", 10 }, /* 0.81 */
{ "ladybug", 4 }, /* 0.81 */
{ "landmakr", 11 }, /* 0.81 */
{ "lastduel", 5 }, /* 0.81 */
{ "lemmings", 5 }, /* 0.81 */
{ "lethalth", 8 }, /* 0.81 */
{ "lgtnfght", 9 }, /* 0.81 */
{ "liblrabl", 8 }, /* 0.81 */
{ "liquidk", 5 }, /* 0.81 */
{ "locomotn", 2 }, /* 0.81 */
{ "loderndf", 19 }, /* 0.81 */
{ "logicpr2", 9 }, /* 0.81 */
{ "losttomb", 2 }, /* 0.81 */
{ "macross2", 4 }, /* 0.81 */
{ "madgear", 5 }, /* 0.81 */
{ "magix", 2 }, /* 0.81 */
{ "magmax", 5 }, /* 0.81 */
{ "mahoudai", 6 }, /* 0.81 */
{ "mainevt", 5 }, /* 0.81 */
{ "majtitl2", 18 }, /* 0.81 */
{ "majtitle", 17 }, /* 0.81 */
{ "maniach", 3 }, /* 0.81 */
{ "mappy", 13 }, /* 0.81 */
{ "marble", 4 }, /* 0.81 */
{ "marvland", 3 }, /* 0.81 */
{ "mayday", 11 }, /* 0.81 */
{ "mayhem", 2 }, /* 0.81 */
{ "mazinger", 5 }, /* 0.81 */
{ "mcatadv", 1 }, /* 0.81 */
{ "megab", 2 }, /* 0.81 */
{ "megaman", 8 }, /* 0.81 */
{ "megaman2", 24 }, /* 0.81 */
{ "mercs", 16 }, /* 0.81 */
{ "metafox", 3 }, /* 0.81 */
{ "metlhawk", 17 }, /* 0.81 */
{ "metmqstr", 5 }, /* 0.81 */
{ "mia", 9 }, /* 0.81 */
{ "mikie", 15 }, /* 0.81 */
{ "minigolf", 10 }, /* 0.81 */
{ "mirninja", 8 }, /* 0.81 */
{ "mk", 3 }, /* 0.81 */
{ "mk2", 2 }, /* 0.81 */
{ "mk3", 11 }, /* 0.81 */
{ "mmatrix", 10 }, /* 0.81 */
{ "mmaze", 3 }, /* 0.81 */
{ "moo", 9 }, /* 0.81 */
{ "moonwar", 2 }, /* 0.81 */
{ "motos", 6 }, /* 0.81 */
{ "mouja", 28 }, /* 0.81 */
{ "msha", 15 }, /* 0.81 */
{ "mshuttle", 3 }, /* 0.81 */
{ "mshvsf", 21 }, /* 0.81 */
{ "mslider", 9 }, /* 0.81 */
{ "mspacman", 5 }, /* 0.81 */
{ "msword", 12 }, /* 0.81 */
{ "mtwins", 9 }, /* 0.81 */
{ "multchmp", 5 }, /* 0.81 */
{ "mvsc", 25 }, /* 0.81 */
{ "mx5000", 5 }, /* 0.81 */
{ "mysticm", 18 }, /* 0.81 */
{ "mysticri", 13 }, /* 0.81 */
{ "naname", 11 }, /* 0.81 */
{ "narc", 16 }, /* 0.81 */
{ "nbahangt", 5 }, /* 0.81 */
{ "nemesis", 9 }, /* 0.81 */
{ "nemo", 17 }, /* 0.81 */
{ "neogeo", 4 }, /* 0.81 */
{ "nibbler", 2 }, /* 0.81 */
{ "nightstr", 10 }, /* 0.81 */
{ "ninjak", 3 }, /* 0.81 */
{ "ninjaw", 10 }, /* 0.81 */
{ "ninjemak", 7 }, /* 0.81 */
{ "niyanpai", 4 }, /* 0.81 */
{ "nost", 14 }, /* 0.81 */
{ "nouryoku", 6 }, /* 0.81 */
{ "nrallyx", 14 }, /* 0.81 */
{ "nstocker", 11 }, /* 0.81 */
{ "nwarr", 19 }, /* 0.81 */
{ "omegaf", 11 }, /* 0.81 */
{ "openice", 23 }, /* 0.81 */
{ "ordyne", 13 }, /* 0.81 */
{ "orunners", 9 }, /* 0.81 */
{ "oscar", 13 }, /* 0.81 */
{ "othldrby", 7 }, /* 0.81 */
{ "outzone", 12 }, /* 0.81 */
{ "overdriv", 7 }, /* 0.81 */
{ "p47", 22 }, /* 0.81 */
{ "pacland", 4 }, /* 0.81 */
{ "pacmania", 3 }, /* 0.81 */
{ "pacnpal", 13 }, /* 0.81 */
{ "pacplus", 5 }, /* 0.81 */
{ "palamed", 3 }, /* 0.81 */
{ "pandoras", 7 }, /* 0.81 */
{ "pang", 5 }, /* 0.81 */
{ "pang3", 8 }, /* 0.81 */
{ "panicstr", 5 }, /* 0.81 */
{ "paperboy", 3 }, /* 0.81 */
{ "parodius", 21 }, /* 0.81 */
{ "pbaction", 11 }, /* 0.81 */
{ "pbancho", 6 }, /* 0.81 */
{ "pbobble", 5 }, /* 0.81 */
{ "pbobble2", 9 }, /* 0.81 */
{ "pbobble3", 12 }, /* 0.81 */
{ "pbobble4", 16 }, /* 0.81 */
{ "peggle", 4 }, /* 0.81 */
{ "penbros", 4 }, /* 0.81 */
{ "pepper2", 39 }, /* 0.81 */
{ "phelios", 17 }, /* 0.81 */
{ "phozon", 13 }, /* 0.81 */
{ "pingpong", 3 }, /* 0.81 */
{ "pipedrm", 34 }, /* 0.81 */
{ "pipibibs", 10 }, /* 0.81 */
{ "pistoldm", 12 }, /* 0.81 */
{ "pitfight", 4 }, /* 0.81 */
{ "pkunwar", 7 }, /* 0.81 */
{ "plgirls2", 5 }, /* 0.81 */
{ "plumppop", 9 }, /* 0.81 */
{ "plusalph", 8 }, /* 0.81 */
{ "pnickj", 6 }, /* 0.81 */
{ "pooyan", 2 }, /* 0.81 */
{ "popnpop", 12 }, /* 0.81 */
{ "poundfor", 12 }, /* 0.81 */
{ "powerdrv", 3 }, /* 0.81 */
{ "powerins", 10 }, /* 0.81 */
{ "prehisle", 5 }, /* 0.81 */
{ "pspikes", 2 }, /* 0.81 */
{ "psychic5", 2 }, /* 0.81 */
{ "psychos", 5 }, /* 0.81 */
{ "puchicar", 11 }, /* 0.81 */
{ "puckman", 5 }, /* 0.81 */
{ "pulirula", 6 }, /* 0.81 */
{ "punisher", 8 }, /* 0.81 */
{ "punkshot", 3 }, /* 0.81 */
{ "pushmans", 4 }, /* 0.81 */
{ "puzlclub", 12 }, /* 0.81 */
{ "puzldama", 14 }, /* 0.81 */
{ "puzzloop", 4 }, /* 0.81 */
{ "puzznic", 6 }, /* 0.81 */
{ "pwrgoal", 12 }, /* 0.81 */
{ "pwrinst2", 11 }, /* 0.81 */
{ "pzlbowl", 10 }, /* 0.81 */
{ "quester", 13 }, /* 0.81 */
{ "rabiolep", 12 }, /* 0.81 */
{ "raimais", 10 }, /* 0.81 */
{ "rainbow", 3 }, /* 0.81 */
{ "rallybik", 9 }, /* 0.81 */
{ "rallyx", 13 }, /* 0.81 */
{ "rampage", 2 }, /* 0.81 */
{ "rampart", 4 }, /* 0.81 */
{ "recordbr", 4 }, /* 0.81 */
{ "reikaids", 6 }, /* 0.81 */
{ "rezon", 6 }, /* 0.81 */
{ "ringdest", 8 }, /* 0.81 */
{ "riotcity", 13 }, /* 0.81 */
{ "rmpgwt", 3 }, /* 0.81 */
{ "roadblst", 5 }, /* 0.81 */
{ "roadf", 8 }, /* 0.81 */
{ "robokid", 40 }, /* 0.81 */
{ "rocnrope", 7 }, /* 0.81 */
{ "rollerg", 18 }, /* 0.81 */
{ "rompers", 11 }, /* 0.81 */
{ "rthun2", 4 }, /* 0.81 */
{ "rtype", 15 }, /* 0.81 */
{ "rtype2", 12 }, /* 0.81 */
{ "rtypeleo", 7 }, /* 0.81 */
{ "rygar", 8 }, /* 0.81 */
{ "ryujin", 8 }, /* 0.81 */
{ "s1945", 3 }, /* 0.81 */
{ "s1945ii", 12 }, /* 0.81 */
{ "s1945iii", 11 }, /* 0.81 */
{ "sailormn", 13 }, /* 0.81 */
{ "salamand", 8 }, /* 0.81 */
{ "samuraia", 2 }, /* 0.81 */
{ "sandscrp", 2 }, /* 0.81 */
{ "sarge", 2 }, /* 0.81 */
{ "sbasketb", 7 }, /* 0.81 */
{ "sbomberb", 11 }, /* 0.81 */
{ "scfinals", 10 }, /* 0.81 */
{ "scobra", 4 }, /* 0.81 */
{ "scontra", 6 }, /* 0.81 */
{ "scramble", 4 }, /* 0.81 */
{ "searchar", 7 }, /* 0.81 */
{ "selfeena", 5 }, /* 0.81 */
{ "sengekis", 5 }, /* 0.81 */
{ "senjyo", 7 }, /* 0.81 */
{ "sexyparo", 11 }, /* 0.81 */
{ "sf1", 11 }, /* 0.81 */
{ "sf2", 15 }, /* 0.81 */
{ "sf2ce", 15 }, /* 0.81 */
{ "sfa", 13 }, /* 0.81 */
{ "sfa2", 22 }, /* 0.81 */
{ "sfa3", 12 }, /* 0.81 */
{ "sfootbal", 10 }, /* 0.81 */
{ "sgemf", 17 }, /* 0.81 */
{ "shadfrce", 22 }, /* 0.81 */
{ "shadowld", 4 }, /* 0.81 */
{ "shangha2", 4 }, /* 0.81 */
{ "shangha3", 14 }, /* 0.81 */
{ "shanghai", 6 }, /* 0.81 */
{ "shippumd", 9 }, /* 0.81 */
{ "shollow", 4 }, /* 0.81 */
{ "showdown", 28 }, /* 0.81 */
{ "shufshot", 2 }, /* 0.81 */
{ "sichuan2", 3 }, /* 0.81 */
{ "sidearms", 5 }, /* 0.81 */
{ "silentd", 5 }, /* 0.81 */
{ "silkroad", 11 }, /* 0.81 */
{ "silkworm", 14 }, /* 0.81 */
{ "simpsons", 10 }, /* 0.81 */
{ "sinistar", 13 }, /* 0.81 */
{ "skyadvnt", 13 }, /* 0.81 */
{ "skykid", 4 }, /* 0.81 */
{ "skykiddx", 9 }, /* 0.81 */
{ "skysmash", 6 }, /* 0.81 */
{ "skysoldr", 16 }, /* 0.81 */
{ "slammast", 8 }, /* 0.81 */
{ "slyspy", 4 }, /* 0.81 */
{ "smashtv", 23 }, /* 0.81 */
{ "snakepit", 10 }, /* 0.81 */
{ "snakjack", 12 }, /* 0.81 */
{ "snapjack", 2 }, /* 0.81 */
{ "snowbro2", 13 }, /* 0.81 */
{ "snowbros", 5 }, /* 0.81 */
{ "sokonuke", 8 }, /* 0.81 */
{ "solarfox", 9 }, /* 0.81 */
{ "soldivid", 12 }, /* 0.81 */
{ "solomon", 11 }, /* 0.81 */
{ "sonicp", 2 }, /* 0.81 */
{ "sonson", 13 }, /* 0.81 */
{ "spacedx", 6 }, /* 0.81 */
{ "spang", 8 }, /* 0.81 */
{ "spbactn", 5 }, /* 0.81 */
{ "spcinv95", 7 }, /* 0.81 */
{ "speedbal", 4 }, /* 0.81 */
{ "spelunkr", 4 }, /* 0.81 */
{ "spf2t", 25 }, /* 0.81 */
{ "spiker", 10 }, /* 0.81 */
{ "spinlbrk", 4 }, /* 0.81 */
{ "splash", 13 }, /* 0.81 */
{ "splat", 11 }, /* 0.81 */
{ "splatter", 12 }, /* 0.81 */
{ "springer", 4 }, /* 0.81 */
{ "spyhunt", 3 }, /* 0.81 */
{ "spyhunt2", 4 }, /* 0.81 */
{ "sqixbl", 11 }, /* 0.81 */
{ "srumbler", 7 }, /* 0.81 */
{ "ssf2", 18 }, /* 0.81 */
{ "ssi", 4 }, /* 0.81 */
{ "ssmissin", 2 }, /* 0.81 */
{ "stadhero", 11 }, /* 0.81 */
{ "starforc", 3 }, /* 0.81 */
{ "stargate", 11 }, /* 0.81 */
{ "starwars", 2 }, /* 0.81 */
{ "stdragon", 11 }, /* 0.81 */
{ "stinger", 4 }, /* 0.81 */
{ "stocker", 11 }, /* 0.81 */
{ "stratab", 8 }, /* 0.81 */
{ "streetsm", 14 }, /* 0.81 */
{ "strider", 3 }, /* 0.81 */
{ "strkforc", 12 }, /* 0.81 */
{ "stunrun", 8 }, /* 0.81 */
{ "superpac", 6 }, /* 0.81 */
{ "suprslam", 4 }, /* 0.81 */
{ "surpratk", 8 }, /* 0.81 */
{ "svolley", 5 }, /* 0.81 */
{ "swimmer", 4 }, /* 0.81 */
{ "sws92", 14 }, /* 0.81 */
{ "sws93", 14 }, /* 0.81 */
{ "sxyreact", 2 }, /* 0.81 */
{ "syvalion", 21 }, /* 0.81 */
{ "tail2nos", 4 }, /* 0.81 */
{ "tapper", 6 }, /* 0.81 */
{ "tattass", 8 }, /* 0.81 */
{ "tbyahhoo", 9 }, /* 0.81 */
{ "tdfever", 5 }, /* 0.81 */
{ "tdragon2", 3 }, /* 0.81 */
{ "tdragonb", 2 }, /* 0.81 */
{ "teddybb", 44 }, /* 0.81 */
{ "teedoff", 9 }, /* 0.81 */
{ "tehkanwc", 6 }, /* 0.81 */
{ "tengai", 3 }, /* 0.81 */
{ "terracre", 2 }, /* 0.81 */
{ "tetrisp2", 6 }, /* 0.81 */
{ "thehustl", 14 }, /* 0.81 */
{ "thndrx2", 5 }, /* 0.81 */
{ "thunderj", 2 }, /* 0.81 */
{ "thunderl", 8 }, /* 0.81 */
{ "thunderx", 6 }, /* 0.81 */
{ "thundfox", 3 }, /* 0.81 */
{ "tigeroad", 8 }, /* 0.81 */
{ "timber", 6 }, /* 0.81 */
{ "timekill", 5 }, /* 0.81 */
{ "timeplt", 5 }, /* 0.81 */
{ "timesold", 16 }, /* 0.81 */
{ "tinklpit", 11 }, /* 0.81 */
{ "tmnt", 11 }, /* 0.81 */
{ "tndrcade", 2 }, /* 0.81 */
{ "tnk3", 9 }, /* 0.81 */
{ "tnzs", 13 }, /* 0.81 */
{ "toggle", 12 }, /* 0.81 */
{ "toobin", 2 }, /* 0.81 */
{ "topsecex", 30 }, /* 0.81 */
{ "toryumon", 11 }, /* 0.81 */
{ "totcarn", 26 }, /* 0.81 */
{ "tp84", 8 }, /* 0.81 */
{ "trackfld", 1 }, /* 0.81 */
{ "tricktrp", 8 }, /* 0.81 */
{ "trisport", 4 }, /* 0.81 */
{ "trog", 2 }, /* 0.81 */
{ "trstar", 5 }, /* 0.81 */
{ "truxton2", 13 }, /* 0.81 */
{ "tshoot", 15 }, /* 0.81 */
{ "tturf", 7 }, /* 0.81 */
{ "turbofrc", 6 }, /* 0.81 */
{ "turtship", 11 }, /* 0.81 */
{ "twinbee", 25 }, /* 0.81 */
{ "twincobr", 12 }, /* 0.81 */
{ "twineagl", 13 }, /* 0.81 */
{ "twinqix", 9 }, /* 0.81 */
{ "uballoon", 7 }, /* 0.81 */
{ "ultraman", 22 }, /* 0.81 */
{ "ultrax", 7 }, /* 0.81 */
{ "undrfire", 7 }, /* 0.81 */
{ "unsquad", 3 }, /* 0.81 */
{ "uopoko", 10 }, /* 0.81 */
{ "upndown", 4 }, /* 0.81 */
{ "varth", 9 }, /* 0.81 */
{ "vasara", 3 }, /* 0.81 */
{ "vhunt2r1", 19 }, /* 0.81 */
{ "victroad", 6 }, /* 0.81 */
{ "vindctr2", 2 }, /* 0.81 */
{ "vindictr", 2 }, /* 0.81 */
{ "vsav", 20 }, /* 0.81 */
{ "vsav2", 19 }, /* 0.81 */
{ "vulcan", 15 }, /* 0.81 */
{ "vulgus", 1 }, /* 0.81 */
{ "wacko", 8 }, /* 0.81 */
{ "wallst", 13 }, /* 0.81 */
{ "wardner", 32 }, /* 0.81 */
{ "warriorb", 8 }, /* 0.81 */
{ "wbmlb", 3 }, /* 0.81 */
{ "wc90", 10 }, /* 0.81 */
{ "wcbowl", 3 }, /* 0.81 */
{ "wecleman", 7 }, /* 0.81 */
{ "welltris", 20 }, /* 0.81 */
{ "wgp", 19 }, /* 0.81 */
{ "willow", 4 }, /* 0.81 */
{ "wiping", 7 }, /* 0.81 */
{ "wiz", 3 }, /* 0.81 */
{ "wizdfire", 7 }, /* 0.81 */
{ "wldcourt", 11 }, /* 0.81 */
{ "wndrmomo", 15 }, /* 0.81 */
{ "wndrplnt", 5 }, /* 0.81 */
{ "wof", 8 }, /* 0.81 */
{ "wrofaero", 7 }, /* 0.81 */
{ "ws", 11 }, /* 0.81 */
{ "wwfmania", 5 }, /* 0.81 */
{ "wwfsstar", 9 }, /* 0.81 */
{ "wwfwfest", 9 }, /* 0.81 */
{ "xenophob", 3 }, /* 0.81 */
{ "xevious", 12 }, /* 0.81 */
{ "xexex", 14 }, /* 0.81 */
{ "xmcota", 16 }, /* 0.81 */
{ "xmen", 21 }, /* 0.81 */
{ "xmultipl", 4 }, /* 0.81 */
{ "xmvsf", 17 }, /* 0.81 */
{ "xsleena", 2 }, /* 0.81 */
{ "xxmissio", 7 }, /* 0.81 */
{ "yiear", 4 }, /* 0.81 */
{ "zeropnt", 10 }, /* 0.81 */
{ "zeropnt2", 11 }, /* 0.81 */
{ "zerowing", 4 }, /* 0.81 */
{ "zingzip", 3 }, /* 0.81 */
{ "zodiack", 3 }, /* 0.81 */
{ "zwackery", 4 }, /* 0.81 */
